@@ -1,7 +1,7 @@
 import requests
 from bs4 import BeautifulSoup
 
-from diningcodeapi.config import HEADERS
+from diningcodeapi.config import HEADERS, API_VERSION_V1
 
 
 class BlogMixin:
@@ -19,17 +19,19 @@ class BlogMixin:
         blog_tags = soup.find_all("li")
 
         blogs = []
-        for blog_tag in blog_tags:
+        for i, blog_tag in enumerate(blog_tags):
             title = blog_tag.find("span", class_='btxt').get_text()
             content = blog_tag.find("span", class_='stxt').get_text()
             author_name = blog_tag.find("span", class_="person").get_text()
             date = blog_tag.find("span", class_="date").get_text()
 
             blogs.append({
+                "_id":f'{store_code}_{page_no}_{i}',
                 "title": title,
                 "content": content,
                 "author_name": author_name,
-                "date": date
+                "date": date,
+                "api-version":API_VERSION_V1
             })
 
         return blogs
\ No newline at end of file
